using YBEE.EQM.Core;

namespace YBEE.EQM.Application
{
    public interface ISysLogService
    {
        Task ClearLogVis();
        Task<PageResult<SysLogVisOutput>> QueryLogVisPageList(SysLogVisPageInput input);

        Task ClearLogEx();
        Task<PageResult<SysLogExOutput>> QueryLogExPageList(SysLogExPageInput input);

        Task ClearLogOp();
        Task<PageResult<SysLogOpOutput>> QueryLogOpPageList(SysLogOpPageInput input);
    }
}